bayespy.inference.vmp.transformations.RotationOptimizer.__init__
================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotationOptimizer.__init__